@@ -1,10 +1,3 @@
-
-H<-function(m,a,b,n){
-if(n>=b) invisible(choose(a,m)*choose(n-a,b-m)/choose(n,b))
-else if(n>=a) invisible(choose(b,m)*choose(n-b,a-m)/choose(n,a))
-else return(NaN)
-}
-
 # Old algorithm
 PXisMclassic<-function(m,n,Nt,k){
 k_1<-k-1
